==> Bundle-Modules-2006.0510.tar.gz: Bundle-Modules-2006.0510/Modules.pm <==
package Bundle::Modules;

$VERSION = 2006.0510; ## (YYYY.MMDD)

1;

__END__

=head1 NAME

Bundle::Modules - All current stable bundles of modules in CPAN

=head1 SYNOPSIS

C<perl -MCPAN -e 'install Bundle::Modules'>

C<cpan -i Bundle::Modules>

=head1 CONTENTS
Bundle::DBD::InterBase
Bundle::Apache2
Bundle::BDFOY
Bundle::SNMP::MIB::Compiler
Bundle::Business::Shipping::DataTools
Bundle::DBD::Informix
Bundle::ParallelUA
Bundle::Cisco::Conf
Bundle::MusicBrainz::Server
Bundle::Perl6
Bundle::NiceSleep
Bundle::HTMLWikiConverter
Bundle::Text::Query::BuildSQL
Bundle::Apache::ASP
Bundle::TreeDumper
Bundle::Net::Nessus
Bundle::Tie::FormA
Bundle::WWW::Scraper::Housing
Bundle::Math::Numeric
Bundle::OurNet
Bundle::Maypole
Bundle::DataMint
Bundle::DBD::mSQL
Bundle::SNMP::Monitor
Bundle::Interchange4
Bundle::OS2_default6
Bundle::DBD::DB2
Bundle::Latemp
Bundle::DateTime::Complete
Bundle::KohaSupport
Bundle::Wombat
Bundle::Phalanx100
Bundle::SSH
Bundle::Search::InvertedIndex
Bundle::Math::Base
Bundle::OpenInteract
Bundle::BricolagePlus
Bundle::CPANPLUS
Bundle::Cascade
Bundle::Math::Random
Bundle::CPANPLUS::Test::Reporter
Bundle::Lingua::PT
Bundle::Apache::Wombat
Bundle::Starlink::Base
Bundle::MP3
Bundle::Egrail
Bundle::Urchin
Bundle::SQL::Translator
Bundle::Business::Shipping::UPS_Online
Bundle::QuadPres
Bundle::Bugzilla
Bundle::RT
Bundle::WormBase
Bundle::HTML::Mason
Bundle::Math::Fractal
Bundle::CPANPLUS::Dependencies
Bundle::Math::Big
Bundle::PPT
Bundle::Math::Approx
Bundle::Kwiki
Bundle::SPOPS
Bundle::Markup
Bundle::LawMonkey
Bundle::Sledge::I18N
Bundle::Math
Bundle::DBD::Yaswi
Bundle::CGI::Builder::Complete
Bundle::BioPerl
Bundle::OS2_default3
Bundle::Business::Shipping
Bundle::Schwern
Bundle::Math::Statistics
Bundle::Posy
Bundle::Xmms
Bundle::ePortal
Bundle::Mail::IspMailGate
Bundle::MusicBrainz::Client
Bundle::CPAN
Bundle::POE::All
Bundle::W3C::Validator
Bundle::Combust::Extras
Bundle::Knetrix
Bundle::Math::Financial
Bundle::libservlet
Bundle::SDK::COG
Bundle::WWW::Mechanize::Shell
Bundle::Tree::Simple
Bundle::Wizard
Bundle::Gnome2
Bundle::Slash
Bundle::Wizard::LDAP
Bundle::SDK::SIMON
Bundle::Expect
Bundle::CpanTestDummies
Bundle::Math::Calculus
Bundle::Zavitan
Bundle::Test
Bundle::Math::Matrix
Bundle::IspMailGate
Bundle::perlWebSite
Bundle::COG
Bundle::InterchangeKitchenSink
Bundle::XML
Bundle::Devel
Bundle::Rose
Bundle::Business::Shipping::Basic
Bundle::Minivend
Bundle::Apache::ASP::Extra
Bundle::AMBS
Bundle::DBD::CSV
Bundle::Business::Shipping::UPS_Offline
Bundle::GMOD
Bundle::Ovid
Bundle::WING
Bundle::ebx
Bundle::OpenILS
Bundle::OS2_default
Bundle::Delivery
Bundle::Email
Bundle::HTTP::WebTest
Bundle::Everything
Bundle::Net::LDAP
Bundle::HTML::EP
Bundle::Pgreet
Bundle::Alphamail
Bundle::Bricolage
Bundle::OpenSRF
Bundle::Pugs::SmokeKit
Bundle::OS2_default5
Bundle::Combust
Bundle::myxCal
Bundle::Apache::Roaming
Bundle::ABH::Apache
Bundle::Template::Magic
Bundle::Msql
Bundle::OS2_default2
Bundle::OS2_default7
Bundle::MMS::Mail::Parser
Bundle::Pipe
Bundle::Mysql
Bundle::ABH
Bundle::Tie::DB_File::SplitHash
Bundle::Net::SXIP::Homesite
Bundle::Link_Controller
Bundle::Zoidberg
Bundle::Interchange
Bundle::Math::Symbolic
Bundle::PerlPoint
Bundle::OS2_default1
Bundle::Apache
Bundle::DBD::JDBC
Bundle::Sites::BetterScm
Bundle::Business::Shipping::USPS_Online
Bundle::Math::Geometry
Bundle::OpenInteract2
Bundle::CUFTS
Bundle::Tk_OS2src
Bundle::MyLibrary
Bundle::Sledge
Bundle::Bonsai
Bundle::Application::Magic
Bundle::OS2_default1_2
Bundle::Catalog
Bundle::PlRPC
Bundle::Cobalt
Bundle::DBI
Bundle::Math::Interface
Bundle::Olive
Bundle::libnet
Bundle::Query
Bundle::LWP
Bundle::CVSMonitor
Bundle::ApacheTest
Bundle::Math::Expression
Bundle::OS2_default4
Bundle::DBD::mysql
Bundle::WWW::Search::Scraper::Housing
=head1 CHANGES

=over 4

=item 0.01

This is Bundle::Modules initial version 2006.0510 (YYYY.MMDD)

This C<Bundle::Modules> component package is in pre-alpha state with hash ordering.

The ordering of listed modules will eventually be prioritized for efficiency and completeness.

Modules commented out of this module list are either unstable or stable in the C<Bundle::Modules> context.

Optimistically, if there are a lot of the modules commented out, then they are stable, and we're listing unstable context.

Optimistically, if there are a few of the modules commented out, then they are unstable, and we're listing stable context.

=back

=head1 AUTHOR

Eric R. Meyers (CPAN author/id/E/ER/ERMEYERS/Bundle-Modules-2006.0510)

==> Bundle-Modules-2006.0511.tar.gz: Bundle-Modules-2006.0511/Modules.pm <==
package Bundle::Modules;

$VERSION = 2006.0511; ## (YYYY.MMDD)

1;

__END__

=head1 NAME

=over

=item Bundle::Modules

All current I<stable> bundles of modules in CPAN

=back

=head1 SYNOPSIS

=over

=item C<% B<perl -MCPAN -e 'install Bundle::Modules'>>

=item C<% B<cpan -i Bundle::Modules>>

=back

=head1 CONTENTS

Bundle::DBD::InterBase
Bundle::Apache2
Bundle::BDFOY
Bundle::SNMP::MIB::Compiler
Bundle::Business::Shipping::DataTools
Bundle::DBD::Informix
Bundle::ParallelUA
Bundle::Cisco::Conf
Bundle::MusicBrainz::Server
Bundle::Perl6
Bundle::NiceSleep
Bundle::HTMLWikiConverter
Bundle::Text::Query::BuildSQL
Bundle::Apache::ASP
Bundle::TreeDumper
Bundle::Net::Nessus
Bundle::Tie::FormA
Bundle::Math::Numeric
Bundle::OurNet
Bundle::Maypole
Bundle::DataMint
Bundle::DBD::mSQL
Bundle::SNMP::Monitor
Bundle::Interchange4
Bundle::OS2_default6
Bundle::DBD::DB2
Bundle::Latemp
Bundle::DateTime::Complete
Bundle::KohaSupport
Bundle::Wombat
Bundle::Phalanx100
Bundle::SSH
Bundle::Search::InvertedIndex
Bundle::Math::Base
Bundle::OpenInteract
Bundle::BricolagePlus
Bundle::CPANPLUS
Bundle::Cascade
Bundle::Math::Random
Bundle::CPANPLUS::Test::Reporter
Bundle::Lingua::PT
Bundle::Apache::Wombat
Bundle::Starlink::Base
Bundle::MP3
Bundle::Egrail
Bundle::Urchin
Bundle::SQL::Translator
Bundle::Business::Shipping::UPS_Online
Bundle::QuadPres
Bundle::Bugzilla
Bundle::RT
Bundle::WormBase
Bundle::HTML::Mason
Bundle::Math::Fractal
Bundle::CPANPLUS::Dependencies
Bundle::Math::Big
Bundle::PPT
Bundle::Math::Approx
Bundle::Kwiki
Bundle::SPOPS
Bundle::Markup
##Bundle::WWW::Search::Scraper::Housing
Bundle::LawMonkey
Bundle::Sledge::I18N
Bundle::Math
Bundle::DBD::Yaswi
Bundle::CGI::Builder::Complete
Bundle::BioPerl
Bundle::OS2_default3
Bundle::Business::Shipping
Bundle::Schwern
Bundle::Math::Statistics
Bundle::Posy
Bundle::Xmms
Bundle::ePortal
Bundle::Mail::IspMailGate
Bundle::MusicBrainz::Client
Bundle::CPAN
Bundle::POE::All
Bundle::W3C::Validator
Bundle::Combust::Extras
Bundle::Knetrix
Bundle::Math::Financial
Bundle::libservlet
Bundle::SDK::COG
Bundle::WWW::Mechanize::Shell
Bundle::Tree::Simple
Bundle::Wizard
Bundle::Gnome2
Bundle::Slash
Bundle::Wizard::LDAP
Bundle::SDK::SIMON
Bundle::Expect
Bundle::CpanTestDummies
Bundle::Math::Calculus
Bundle::Zavitan
Bundle::Test
Bundle::Math::Matrix
Bundle::IspMailGate
Bundle::perlWebSite
Bundle::COG
Bundle::InterchangeKitchenSink
Bundle::XML
Bundle::Devel
Bundle::Rose
Bundle::Business::Shipping::Basic
Bundle::Minivend
Bundle::Apache::ASP::Extra
Bundle::AMBS
Bundle::DBD::CSV
Bundle::Business::Shipping::UPS_Offline
Bundle::GMOD
Bundle::Ovid
Bundle::WING
Bundle::ebx
Bundle::OpenILS
Bundle::OS2_default
Bundle::Delivery
Bundle::Email
Bundle::HTTP::WebTest
Bundle::Everything
Bundle::Net::LDAP
Bundle::HTML::EP
Bundle::Pgreet
Bundle::Alphamail
Bundle::Bricolage
Bundle::OpenSRF
Bundle::Pugs::SmokeKit
Bundle::OS2_default5
Bundle::Combust
Bundle::myxCal
Bundle::Apache::Roaming
Bundle::ABH::Apache
##Bundle::WWW::Scraper::Housing
Bundle::Template::Magic
Bundle::Msql
Bundle::OS2_default2
Bundle::OS2_default7
Bundle::MMS::Mail::Parser
Bundle::Pipe
Bundle::Mysql
Bundle::ABH
Bundle::Tie::DB_File::SplitHash
Bundle::Net::SXIP::Homesite
Bundle::Link_Controller
Bundle::Zoidberg
Bundle::Interchange
Bundle::Math::Symbolic
Bundle::PerlPoint
Bundle::OS2_default1
Bundle::Apache
Bundle::DBD::JDBC
Bundle::Sites::BetterScm
Bundle::Business::Shipping::USPS_Online
Bundle::Math::Geometry
Bundle::OpenInteract2
Bundle::CUFTS
Bundle::Tk_OS2src
Bundle::MyLibrary
Bundle::Sledge
Bundle::Bonsai
Bundle::Application::Magic
Bundle::OS2_default1_2
Bundle::Catalog
Bundle::PlRPC
Bundle::Cobalt
Bundle::DBI
Bundle::Math::Interface
Bundle::Olive
Bundle::libnet
Bundle::Query
Bundle::LWP
Bundle::CVSMonitor
Bundle::ApacheTest
Bundle::Math::Expression
Bundle::OS2_default4
Bundle::DBD::mysql

=head1 CHANGES

=over

=item 2006.0510 (YYYY.MMDD)

Initial version of: Bundle::Modules-2006.0510

This B<L<Bundle::Modules>> component package is in pre-alpha state with hash ordering.

The ordering of listed modules will eventually be prioritized for efficiency and completeness.

Modules commented out of this module list are either I<unstable> or I<stable> in the B<L<Bundle::Modules>> context.

Optimistically, if there are a lot of the modules commented out, then they are I<stable>, and we're listing I<unstable> context.

Optimistically, if there are a few of the modules commented out, then they are I<unstable>, and we're listing I<stable> context.

If you use the command C<B<man Bundle::Modules>>, type C<B</#>> to see the commented out modules as they're higlighted for you by B<L<man>>.

=back

=head1 DESCRIPTION

=over

=item This Bundle package will install all of the modules listed, if they're not commented out of the B<L<Bundle::Modules>> context.

=back

=head1 SEE ALSO

=over

=item I<L<Bundle::Modules::Unstable>>, I<L<Bundle::Modules::CPAN>>, I<L<Bundle::Modules::CPAN::Unstable>>, I<L<Bundle::Modules::Acme::Everything>>, I<L<Bundle::Modules::Acme::Everything::Unstable>>, I<L<Bundle::Modules::Acme::Everything::Unique>>, I<L<Bundle::Modules::Acme::Everything::Unique::Unstable>>

=back

=head1 AUTHORS

=over

=item Eric R. Meyers E<lt>ermeyers@adelphia.netE<gt>

=back

=head1 LICENSE for http://www.cpan.org/modules/by-authors/id/E/ER/ERMEYERS/Bundle-Modules-2006.0511

=over

=item http://www.perl.com/perl/misc/Artistic.html

=item This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.

=back

=head1 COPYRIGHT

=over

=item Copyright 2006 by Eric R. Meyers E<lt>ermeyers@adelphia.netE<gt>

=back
